Struct GoalEvaluation
pub(crate) struct GoalEvaluation<I>where
I: Interner,{
pub uncanonicalized_goal: Goal<I, <I as Interner>::Predicate>,
pub orig_values: Vec<<I as Interner>::GenericArg>,
pub final_revision: <I as Interner>::Probe,
pub result: Result<Canonical<I, Response<I>>, NoSolution>,
}Expand description
When evaluating a goal we also store the original values
for the CanonicalVarValues of the canonicalized goal.
We use this to map any CanonicalState from the local InferCtxt
of the solver query to the InferCtxt of the caller.
Fields
uncanonicalized_goal: Goal<I, <I as Interner>::Predicate>orig_values: Vec<<I as Interner>::GenericArg>final_revision: <I as Interner>::Proberesult: Result<Canonical<I, Response<I>>, NoSolution>Trait Implementations
impl<I> Hash for GoalEvaluation<I>where
I: Interner,
impl<I> Hash for GoalEvaluation<I>where
I: Interner,
impl<I> PartialEq for GoalEvaluation<I>where
I: Interner,
impl<I> PartialEq for GoalEvaluation<I>where
I: Interner,
fn eq(&self, __other: &GoalEvaluation<I>) -> bool
fn eq(&self, __other: &GoalEvaluation<I>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<I> Eq for GoalEvaluation<I>where
I: Interner,