pub(crate) struct NormalizesToTermHack<'db> {
term: Term<'db>,
unconstrained_term: Term<'db>,
}Expand description
The expected term of a NormalizesTo goal gets replaced
with an unconstrained inference variable when computing
NormalizesTo goals and we return the nested goals to the
caller, who also equates the actual term with the expected.
This is an implementation detail of the trait solver and
not something we want to leak to users. We therefore
treat NormalizesTo goals as if they apply the expected
type at the end of each candidate.
Fields
term: Term<'db>unconstrained_term: Term<'db>Implementations
Sourceimpl<'db> NormalizesToTermHack<'db>
impl<'db> NormalizesToTermHack<'db>
Sourcefn constrain_and(
&self,
infcx: &InferCtxt<'db>,
param_env: ParamEnv<'db>,
f: impl FnOnce(&mut ObligationCtxt<'_, 'db>),
) -> Result<Certainty, NoSolution>
fn constrain_and( &self, infcx: &InferCtxt<'db>, param_env: ParamEnv<'db>, f: impl FnOnce(&mut ObligationCtxt<'_, 'db>), ) -> Result<Certainty, NoSolution>
Relate the term with the new unconstrained_term created
when computing the proof tree for this NormalizesTo goals.
This handles nested obligations.