pub(crate) struct InspectGoal<'a, 'db> {
infcx: &'a SolverContext<'db>,
depth: usize,
orig_values: Vec<GenericArg<'db>>,
goal: Goal<'db, Predicate<'db>>,
result: Result<Certainty, NoSolution>,
final_revision: Probe<DbInterner<'db>>,
normalizes_to_term_hack: Option<NormalizesToTermHack<'db>>,
source: GoalSource,
}Fields
infcx: &'a SolverContext<'db>depth: usizeorig_values: Vec<GenericArg<'db>>goal: Goal<'db, Predicate<'db>>result: Result<Certainty, NoSolution>final_revision: Probe<DbInterner<'db>>normalizes_to_term_hack: Option<NormalizesToTermHack<'db>>source: GoalSourceImplementations
Sourceimpl<'a, 'db> InspectGoal<'a, 'db>
impl<'a, 'db> InspectGoal<'a, 'db>
pub(crate) fn infcx(&self) -> &'a InferCtxt<'db>
pub(crate) fn goal(&self) -> Goal<'db, Predicate<'db>>
pub(crate) fn result(&self) -> Result<Certainty, NoSolution>
pub(crate) fn source(&self) -> GoalSource
pub(crate) fn depth(&self) -> usize
fn candidates_recur( &'a self, candidates: &mut Vec<InspectCandidate<'a, 'db>>, steps: &mut Vec<&'a ProbeStep<DbInterner<'db>>>, probe: &'a Probe<DbInterner<'db>>, )
pub(crate) fn candidates(&'a self) -> Vec<InspectCandidate<'a, 'db>>
Sourcepub(crate) fn unique_applicable_candidate(
&'a self,
) -> Option<InspectCandidate<'a, 'db>>
pub(crate) fn unique_applicable_candidate( &'a self, ) -> Option<InspectCandidate<'a, 'db>>
Returns the single candidate applicable for the current goal, if it exists.
Returns None if there are either no or multiple applicable candidates.
pub(crate) fn new( infcx: &'a InferCtxt<'db>, depth: usize, root: GoalEvaluation<DbInterner<'db>>, term_hack_and_nested_certainty: Option<(NormalizesToTermHack<'db>, Result<Certainty, NoSolution>)>, source: GoalSource, ) -> Self
pub(crate) fn visit_with<V: ProofTreeVisitor<'db>>( &self, visitor: &mut V, ) -> V::Result